﻿#load @"packages\FSharp.Charting.0.90.13\FSharp.Charting.fsx"
open FSharp.Charting
open System

// type providers for CSV, World Bank, etc. can be downloaded through NuGet. Documentation is here:
// http://fsharp.github.io/FSharp.Data/
#r @"packages\FSharp.Data.2.2.5\lib\net40\FSharp.Data.dll"
open FSharp.Data

// Crimes
//

[<Literal>]
let fPath = @"datasets\rec-crime-1898-2002.csv"

// Set up the type provider
type Crimes = CsvProvider<fPath, Separators=",", IgnoreErrors=true, HasHeaders=true>
type CrimeYear = Crimes.Row

let crimeYear = Crimes.Load(fPath).Rows |> Seq.toArray

crimeYear.[0].Year

crimeYear |> Array.map (fun y -> y.Year, y.Blackmail)
|> Chart.Line |> Chart.WithTitle("Blackmail")


// Deedle is a data science library. It is also available through NuGet.
// More information here: 
// http://bluemountaincapital.github.io/Deedle/
// http://bluemountaincapital.github.io/Deedle/tutorial.html
//
#load "packages\Deedle.1.2.4\Deedle.fsx"
open Deedle
// Deedle + F# interactive can't handle relative paths very well - please change the path before running the next line
let ww2Frame = Frame.ReadCsv(@"C:\Users\anjov\Documents\Visual Studio 2015\Projects\fsharp-data-scripts\rec-crime-1898-2002.csv", hasHeaders=true) 
                |> Frame.indexRowsInt "Year"

// Peaks during WWs
//
let ratioBetweenWWMeanAndTotalMean (series : Series<int, float>)=
    let totalMean = series |> Stats.mean
    let wwMean = Series.merge series.[1914..1918] series.[1939..1945] |> Stats.mean
    wwMean / totalMean

ww2Frame
|> Frame.getNumericCols
|> Series.mapValues ratioBetweenWWMeanAndTotalMean
|> Series.sort
|> Series.takeLast 5

[
    crimeYear 
    |> Array.map (fun y -> y.Year, y.Bigamy)
    |> fun d -> Chart.Line (d, Name = "Bigamy");

    crimeYear 
    |> Array.map (fun y -> y.Year, y.``Procuring   illegal abortion``)
    |> fun d -> Chart.Line (d, Name = "illegal abortion")

    crimeYear 
    |> Array.map (fun y -> y.Year, y.Riot)
    |> fun d -> Chart.Line (d, Name = "Riot")


] |> Chart.Combine |> Chart.WithLegend()


// riots look like noise... let's make a more generic function
// That wil allow us to exclude the second half of the 20th century
//
let ratioBetweenWWMeanAndRangeMean beginYear endYear (series : Series<int, float>) =
    let totalMean = series.[beginYear..endYear] |> Stats.mean
    let wwMean = Series.merge series.[1914..1918] series.[1939..1945] |> Stats.mean
    wwMean / totalMean


ww2Frame
|> Frame.getNumericCols
|> Series.mapValues (ratioBetweenWWMeanAndRangeMean 1900 1950)
|> Series.sort
|> Series.takeLast 10